summaryrefslogtreecommitdiffstats
path: root/kftpgrabber/src/misc/interfaces/kftpbookmarkimportplugin.h
diff options
context:
space:
mode:
Diffstat (limited to 'kftpgrabber/src/misc/interfaces/kftpbookmarkimportplugin.h')
-rw-r--r--kftpgrabber/src/misc/interfaces/kftpbookmarkimportplugin.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kftpgrabber/src/misc/interfaces/kftpbookmarkimportplugin.h b/kftpgrabber/src/misc/interfaces/kftpbookmarkimportplugin.h
index e82a718..5f42ccf 100644
--- a/kftpgrabber/src/misc/interfaces/kftpbookmarkimportplugin.h
+++ b/kftpgrabber/src/misc/interfaces/kftpbookmarkimportplugin.h
@@ -36,7 +36,7 @@
#ifndef KFTPBOOKMARKIMPORTPLUGIN_H
#define KFTPBOOKMARKIMPORTPLUGIN_H
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
/**
* This class is the base class for all bookmark import plugins.
@@ -46,23 +46,23 @@
class KFTPBookmarkImportPlugin : public KParts::Plugin {
Q_OBJECT
public:
- KFTPBookmarkImportPlugin(QObject *parent, const char *name = 0);
+ KFTPBookmarkImportPlugin(TQObject *parent, const char *name = 0);
virtual ~KFTPBookmarkImportPlugin();
/**
* This method should return the properly formated XML for KFTPGrabber
* bookmarks that is generated from the import.
*
* @return The @ref QDomDocument representation of XML
*/
- virtual QDomDocument getImportedXml() = 0;
+ virtual TQDomDocument getImportedXml() = 0;
/**
* This method should start the import procedure.
*
* @param fileName is the path to the file that will be imported
*/
- virtual void import(const QString &fileName) = 0;
+ virtual void import(const TQString &fileName) = 0;
/**
* This method should return the default path where the bookmarks could
@@ -70,9 +70,9 @@ public:
*
* @return The default path where bookmarks are located
*/
- virtual QString getDefaultPath() = 0;
+ virtual TQString getDefaultPath() = 0;
protected:
- QString userPath(const QString &path);
+ TQString userPath(const TQString &path);
signals:
/**
* Progress of bookmark importing (in percent).
@@ -46,23 +46,23 @@
* bookmarks that is generated from the import.
*
- * @return The @ref QDomDocument representation of XML
+ * @return The @ref TQDomDocument representation of XML
*/